@@ -8,7 +8,7 @@ import logging.handlers
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
 handler = logging.handlers.SysLogHandler(address='/dev/log')
-formatter = logging.Formatter('%(module)s.%(funcName)s: %(message)s')
+formatter = logging.Formatter(f'%(module)s.{__name__}: %(message)s')
 handler.setFormatter(formatter)
 log.addHandler(handler)
 
